<?php

declare(strict_types=1);
/**
 * @copyright Copyright (c) 2023 Thomas Citharel <nextcloud@tcit.fr>
 *
 * @author Thomas Citharel <nextcloud@tcit.fr>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\DropAccount;

use OCA\DropAccount\AppInfo\Application;
use OCA\DropAccount\Service\DeletionCapabilityService;
use OCP\Capabilities\ICapability;
use OCP\IConfig;
use OCP\IL10N;
use OCP\IUserSession;

class Capabilities implements ICapability {

	private IUserSession $userSession;
	private DeletionCapabilityService $deletionCapabilityService;
	private IConfig $config;
	private IL10N $l10n;

	public function __construct(IUserSession $userSession, DeletionCapabilityService $deletionCapabilityService, IConfig $config, IL10N $l10n) {
		$this->userSession = $userSession;
		$this->deletionCapabilityService = $deletionCapabilityService;
		$this->config = $config;
		$this->l10n = $l10n;
	}

	/**
	 * @return array{drop-account: array{enabled: boolean, api-version: string, delay: array{enabled: bool, hours: int}, details: string|null}}
	 */
	public function getCapabilities(): array {
		[$enabled, $details] = $this->canUserBeDeleted();
		return ['drop-account' =>
			[
				'enabled' => $enabled,
				'delay' => [
					'enabled' => $this->config->getAppValue(Application::APP_NAME, 'delayPurge', 'no') === 'yes',
					'hours' => (int) $this->config->getAppValue(Application::APP_NAME, 'delayPurgeHours', '24'),
				],
				'details' => $details,
				'api-version' => 'v1',
			]
		];
	}

	/**
	 * @return list{boolean, string|null}
	 */
	private function canUserBeDeleted(): array {
		$user = $this->userSession->getUser();
		if (!$user) {
			return [false, $this->l10n->t('User session not found')];
		}
		return $this->deletionCapabilityService->canUserBeDeleted($user);
	}
}
